# Python Package Exercise: simple-pokedex

An exercise to create a Python package, build it, test it, distribute it, and use it. See [instructions](./instructions.md) for details.

Workflow Status Badge: (to be made)

This python package is a simple Pokedex that is able to generate a random Pokedex entry based on Pokemon Generation, search by name or Pokemon ID, give information on each specific Pokemon type.

# About

`simple-pokedex` is a package that provides information about Pokemon using the PokeAPI. Information such as Pokemon abilities, types, and generations can be retrieved.

# Implementation

To install, use `pip install simple-pokedex`.

To import, use `import simple-pokedex`

# Team Members

- [Eric Lin](https://github.com/exl7954)
- [Alice Ding](https://github.com/ayd2134)
- [Justin Zhao](https://github.com/zhaojustin)
